function [out_data] = SAGUARO_LoadData(filename,extension)
%SAGUARO_LoadData allows data to be loaded into SAGUARO datasets.  Consults the
%documentation for more information.

switch lower(extension)
    case 'h5' %This needs TLC
        tempinfo=hdf5info(filename);
        if ~isempty(tempinfo.GroupHierarchy.Groups(1,2).Groups(1,3).Datasets)
            datasetname=tempinfo.GroupHierarchy.Groups(1,2).Groups(1,3).Datasets.Name;
            out_data=hdf5read(filename, datasetname);
        else
            for ii=1:length(tempinfo.GroupHierarchy.Groups(1,2).Groups(1,3).Groups)
                if isfield(tempinfo.GroupHierarchy.Groups(1,2).Groups(1,3).Groups(1,ii).Datasets, 'Name')
                    datasetname=tempinfo.GroupHierarchy.Groups(1,2).Groups(1,3).Groups(1,ii).Datasets.Name;
                end
                
                if ~exist('out_data','var')
                    out_data=hdf5read(filename, datasetname);
                else
                    out_data(:,:,end+1)=hdf5read(filename, datasetname); %stack frames
                end
            end
            
            temp=zeros(size(out_data, 1), size(out_data,2));
            for ii=1:size(out_data,3)
                temp=temp+out_data(:,:,ii);
            end
            out_data=temp./size(out_data,3);
        end
    case 'int' %This needs TLC
        fid=fopen(filename);
        tempdata=textscan(fid,'%d16  %d16  %d16  %d16  %d16  %d16  %d16  %d16  %d16  %d16','HeaderLines',3,'CollectOutput',1);
        tempdata=tempdata{1};
        tempdata=double(tempdata);
        tempdata=tempdata';
        tempdata=tempdata(:);
        dsize=sqrt(length(tempdata));
        tempdata=reshape(tempdata,[dsize dsize]);
        tempdata(tempdata==32767)=NaN;
        out_data=tempdata;
    case 'opd' %This needs TLC
        fid=fopen(filename);
        x=fread(fid,'single');
        x=x(2027:end);
        x=reshape(x,480,736);
        x(x<-.5)=NaN;
        x(x>.5)=NaN;
        x=circshift(x,44);
        x=flipud(x);
        out_data=x;
        
        
    case 'tif'
        tempdata=importdata(filename);
        out_data=double(tempdata.cdata);
    case 'txt'
        fid=fopen(filename);
        
        layer=1;
        
        jj=1;
        
        out_data=[];
        
        while ~feof(fid)
            fline=sscanf(fgetl(fid), '%f ')';
            
            if ~isempty(fline)
                if isempty(out_data)
                    out_data=fline;
                    
                    jj=2;
                else
                    out_data(jj,:,layer)=fline;
                    
                    jj=jj+1;
                end
            elseif ~isempty(out_data)
                layer=layer+1;
                jj=1;
            else
                continue;
            end
        end
        
        out_data=squeeze(out_data);
        
        fclose(fid);
    otherwise
        out_data=importdata(filename);
end

end

