%% Flip a dataset in the X direction
function [OutCellArray, OutConfig] = FlipX(InCellArray, InConfig)
% This module reverses the order of the data in the dataset along the X
% axis.  This operation is equivalent to the MATLAB fliplr() function.
% It can operate on Map, FreqMap, LayerMap and Mask datatypes.  All
% headers are preserved.  Note that the order of layers in a LayerMap is
% not changed.
%
% Inputs: Map or FreqMap or LayerMap or Mask
% Outputs: Same datatype as input
%
% Author: Adrian Loeff
% Email: aloeff@optics.arizona.edu
%
% Version History:
% 2012/11/15 ARL - Created.

    % Use the inputs as the default outputs
    OutConfig = InConfig;
    OutCellArray = InCellArray;

    % Only handle certain types of datasets
    if ~strcmpi(InCellArray{1}.type, 'map') && ...
       ~strcmpi(InCellArray{1}.type, 'freqmap') && ...
       ~strcmpi(InCellArray{1}.type, 'layermap') && ...
       ~strcmpi(InCellArray{1}.type, 'mask')
        % Dataset type is not supported - do nothing
        return;    
    end

    % Read the input data block
    data = real(InCellArray{1}.data);

    % Flip the data along the X (horizontal) axis for each 2-D layer
    for nLayer = 1:size(data, 3)
        data(:, :, nLayer) = fliplr(data(:, :, nLayer));
    end

    % Copy the flipped data to the output
    OutCellArray{1}.data = data;
end
