function [Outconfig]=MapPlot(InCellArray, Inconfig)
%map_plot plots a map using ImageSC. The raw values with row and column
%numbers are displayed.
%
%Inputs: Map
%Outputs: None
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 8/16/10 - Version 1
% 8/20/11 - version 1.1 Dae Wook Kim letter2dwk@hotmail.com (Detailed
% module description.)
% 11/16/2011 - version 1.2 Greg Smith (add units/scaling to plot)
% 11/16/2011 - version 1.3 Ben Lewis (added z unit label)

% extract header information and data
xSize=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2});
ySize=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2});
xUnit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
yUnit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
zUnit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};
mapData = InCellArray{1}.data;
[xDim,yDim] = size(mapData);

% make figure and label
figure;
imagesc(mapData,'alphadata',~isnan(mapData));
axis square;
set(gca,'XTick',0:xDim/4:xDim);
set(gca,'YTick',0:yDim/4:yDim);
set(gca,'XTickLabel',{num2str(-xSize/2),num2str(-xSize/4),'0',num2str(xSize/4),num2str(xSize/2)});
set(gca,'YTickLabel',{num2str(-ySize/2),num2str(-ySize/4),'0',num2str(ySize/4),num2str(ySize/2)});
xlabel(xUnit);
ylabel(yUnit);
c=colorbar;
set(get(c,'ylabel'),'String', zUnit);

Outconfig=Inconfig;

end

