function [OutCellArray, Outconfig]=MapValueReplace(InCellArray, Inconfig)
%MapValueReplace replaces a user-specified value with NaN in a map.  This
%is usefull for changing the masking value in a map from, for example, -1,
%to the SAGUARO standard of NaN.
%
%Inputs: Map
%Outputs: Map
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 8/17/10 - Version 1
% 8/20/11 - Version 1.1 by Dae Wook Kim letter2dwk@hotmail.com (Improved module description)

Outconfig=Inconfig;

OutCellArray{1}=InCellArray{1};

tmap=InCellArray{1}.data;

RepVal=Inconfig{strcmpi(Inconfig, 'Replacement Value'),2};

validinputs=0;

%Get inptuts
while ~validinputs
    answers = inputdlg({'Replacement Value'},'MapValueReplace',1,{RepVal}); %get value to replace
    if ~isempty(answers)
        tempval=answers{1};              
        tempval=str2double(tempval);

        if ~isempty(tempval)&&isnumeric(tempval) %Check if valid input
            validinputs=1;             
            RepVal=tempval;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
    else
        OutCellArray={};
        return; %If answers is empty, user canceled
    end
end

Outconfig{strcmpi(Outconfig, 'Replacement Value'),2}=num2str(RepVal);

tmap(tmap==RepVal)=NaN;

OutCellArray{1}.data=tmap;

end

